==> Intel%C2%AE-CSME-Runtime-Verification-1.0.0.zip: Intel®-CSME-Runtime-Verification-1.0.0/src/cse_image_items/MetaData.py <==
import json
import logging
from jsonschema import validate
from cse_image_items.ManifestExtension import ClientSystemInfoExtensionExtension
from utils import bytes_to_int


logger = logging.getLogger(__name__)
PCH_NAMES_JSON = 'layout/data/pch_names.json'
PCH_NAMES_SCHEMA_JSON = 'layout/data/JSON schemas/pch_names.json'


class MetaData(object):
    def __init__(self, cse_region):
        logger.info('START Image.__init__ FUNCTION')
        bup_manifest = self.get_BUPManifest(cse_region)
        if bup_manifest == None:
            logger.exception('bup_manifest does not exist')
            raise AttributeError('bup_manifest does not exist')
        self.FW_version = self.get_FW_version(bup_manifest)
        client_system_info_extension = self.get_client_system_info_extension(bup_manifest)
        if client_system_info_extension == None:
            logger.exception('client_system_info_extension does not exist')
            raise AttributeError('client_system_info_extension does not exist')
        self.FW_sku_type = self.get_FW_sku_type(client_system_info_extension)
        self.pch_type = self.get_pch_type(client_system_info_extension)
        if self.FW_version != None:
            try:
                with open(PCH_NAMES_JSON) as pch_names_json:
                    pch_names = json.load(pch_names_json)
                with open(PCH_NAMES_SCHEMA_JSON) as pch_names_schema_json:
                    pch_names_schema = json.load(pch_names_schema_json)
                validate(instance=pch_names, schema=pch_names_schema)
            except Exception:
                logger.info('Exception occurred while reading pch names JSON file')
                raise Exception('Exception occurred while reading pch names JSON file')
            for pch_name, versions in pch_names.items():
                if self.FW_version.startswith(tuple(versions)):
                    self.pch_name = pch_name
                    break
        try:
            logger.info('IMAGE METADATA: FWVersion [%s], FWSkuType [%s], pchType [%s], pchName [%s]' % (
                self.FW_version, self.FW_sku_type, self.pch_type, self.pch_name))
        except AttributeError:
            logger.exception('some of the metadata is missing')
            raise AttributeError('some of the metadata is missing')

    def get_BUPManifest(self, cse_region):
        for bpdt in cse_region.logical_boot_partitions:
            for sub_partition_directory_entry in bpdt.sub_partition_directory_entries:
                if sub_partition_directory_entry.entry_type == 'CSE_BUP':
                    for entry in sub_partition_directory_entry.entries:
                        if entry.is_manifest:
                            return entry.manifest

    def get_client_system_info_extension(self, bup_manifest):
        for extention in bup_manifest.extentions:
            if isinstance(extention, ClientSystemInfoExtensionExtension):
                return extention

    def get_FW_version(self, bup_manifest):
        bin_version = bup_manifest.header.version.bytes_value()
        major = bytes_to_int(bup_manifest.header.version.bytes_value()[:2])
        minor = bytes_to_int(bup_manifest.header.version.bytes_value()[2:4])
        hotfix = bytes_to_int(bup_manifest.header.version.bytes_value()[4:6])
        build = bytes_to_int(bup_manifest.header.version.bytes_value()[6:])
        return '%s.%s.%s.%s' % (major, minor, hotfix, build)

    def get_FW_sku_type(self, client_system_info_extension):
        return client_system_info_extension.sku_type

    def get_pch_type(self, client_system_info_extension):
        if client_system_info_extension.is_H.int_value():
            return 'H'
        elif client_system_info_extension.is_LP.int_value():
            return 'LP'
        else:
            logger.error('PCH type did not detected')
            raise Exception('PCH type did not detected')

==> Intel%C2%AE-CSME-Runtime-Verification-1.1.0.zip: Intel®-CSME-Runtime-Verification-1.1.0/src/cse_image_items/MetaData.py <==
import json
import logging
from jsonschema import validate
from cse_image_items.ManifestExtension import ClientSystemInfoExtensionExtension
from utils.utils import bytes_to_int


logger = logging.getLogger(__name__)
PCH_NAMES_JSON = 'layout/data/pch_names.json'
PCH_NAMES_SCHEMA_JSON = 'layout/data/JSON schemas/pch_names.json'


class MetaData(object):
    def __init__(self, cse_region):
        logger.info('START Image.__init__ FUNCTION')
        bup_manifest = self.get_BUPManifest(cse_region)
        if bup_manifest == None:
            logger.exception('bup_manifest does not exist')
            raise AttributeError('bup_manifest does not exist')
        self.FW_version = self.get_FW_version(bup_manifest)
        client_system_info_extension = self.get_client_system_info_extension(
            bup_manifest)
        if client_system_info_extension == None:
            logger.exception('client_system_info_extension does not exist')
            raise AttributeError('client_system_info_extension does not exist')
        self.FW_sku_type = self.get_FW_sku_type(client_system_info_extension)
        self.pch_type = self.get_pch_type(client_system_info_extension)
        if self.FW_version != None:
            try:
                with open(PCH_NAMES_JSON) as pch_names_json:
                    pch_names = json.load(pch_names_json)
                with open(PCH_NAMES_SCHEMA_JSON) as pch_names_schema_json:
                    pch_names_schema = json.load(pch_names_schema_json)
                validate(instance=pch_names, schema=pch_names_schema)
            except Exception:
                logger.info(
                    'Exception occurred while reading pch names JSON file')
                raise Exception(
                    'Exception occurred while reading pch names JSON file')
            for pch_name, versions in pch_names.items():
                if self.FW_version.startswith(tuple(versions)):
                    self.pch_name = pch_name
                    break
        try:
            logger.info('IMAGE METADATA: FWVersion [%s], FWSkuType [%s], pchType [%s], pchName [%s]' % (
                self.FW_version, self.FW_sku_type, self.pch_type, self.pch_name))
        except AttributeError:
            logger.exception('some of the metadata is missing')
            raise AttributeError('some of the metadata is missing')

    def get_BUPManifest(self, cse_region):
        for bpdt in cse_region.logical_boot_partitions:
            for sub_partition_directory_entry in bpdt.sub_partition_directory_entries:
                if sub_partition_directory_entry.entry_type == 'CSE_BUP':
                    for entry in sub_partition_directory_entry.entries:
                        if entry.is_manifest:
                            return entry.manifest

    def get_client_system_info_extension(self, bup_manifest):
        for extention in bup_manifest.extentions:
            if isinstance(extention, ClientSystemInfoExtensionExtension):
                return extention

    def get_FW_version(self, bup_manifest):
        bin_version = bup_manifest.header.version.bytes_value()
        major = bytes_to_int(bup_manifest.header.version.bytes_value()[:2])
        minor = bytes_to_int(bup_manifest.header.version.bytes_value()[2:4])
        hotfix = bytes_to_int(bup_manifest.header.version.bytes_value()[4:6])
        build = bytes_to_int(bup_manifest.header.version.bytes_value()[6:])
        return '%s.%s.%s.%s' % (major, minor, hotfix, build)

    def get_FW_sku_type(self, client_system_info_extension):
        return client_system_info_extension.sku_type

    def get_pch_type(self, client_system_info_extension):
        if client_system_info_extension.is_H.int_value():
            return 'H'
        elif client_system_info_extension.is_LP.int_value():
            return 'LP'
        else:
            logger.error('PCH type did not detected')
            raise Exception('PCH type did not detected')
